# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2024-11-25 17:06:14
@LastEditTime: 2024-12-18 17:47:36
@LastEditors: HuangJianYi
:description: 枚举类
"""

from enum import Enum
from enum import unique

@unique
class OrderStatus(Enum):
    """
    :description: 订单状态
    """
    WAIT_BUYER_PAY = 1 # 等待买家付款
    SELLER_CONSIGNED_PART = 2 # 卖家部分发货
    WAIT_SELLER_SEND_GOODS = 3 # 等待卖家发货,即:买家已付款
    WAIT_BUYER_CONFIRM_GOODS = 4 # 等待买家确认收货,即:卖家已发货
    TRADE_BUYER_SIGNED = 5 # 买家已签收,货到付款专用
    TRADE_FINISHED = 6 # 交易成功
    TRADE_CLOSED = 7 # 付款以后用户退款成功，交易自动关闭
    TRADE_CANCEL = 8 # 付款以前，卖家或买家主动关闭交易
    BUYER_PART_PAY = 9 # 买家部分支付


@unique
class RefundStatus(Enum):
    """
    :description: 退款状态
    """
    NO_REFUND = 1 # 无退款
    WAIT_SELLER_AGREE = 2 # 买家已经申请退款，等待卖家同意
    WAIT_BUYER_RETURN_GOODS = 3 # 卖家已经同意退款，等待买家退货
    WAIT_SELLER_CONFIRM_GOODS = 4 # 买家已经退货，等待卖家确认收货
    SELLER_REFUSE_BUYER = 5 # 卖家拒绝退款
    CLOSED = 6 # 退款关闭
    SUCCESS = 7 # 退款成功


@unique
class AssetType(Enum):
    """
    :description: 资产类型
    """
    integral = 1  # 积分
    growth = 2  # 成长值

@unique
class RoundingType(Enum):
    """
    :description: 取整类型
    """
    half_up = 1  # 四舍五入
    ceiling = 2  # 向上取整
    floor = 3  # 向下取整

@unique
class ValidType(Enum):
    """
    :description: 有效期类型
    """
    forever = 1  # 永久有效
    limited = 2  # 限制时间

@unique
class ExpireType(Enum):
    """
    :description: 过期类型
    """
    appoint_day = 1  # 指定天
    appoint_datetime = 2  # 指定时间

@unique
class IntegralConfigType(Enum):
    """
    :description: 积分配置类型
    """
    init = 1  # 初始设置
    base = 2  # 基础设置
    shield_reward = 3  # 屏蔽/奖励设置
    deduct = 4  # 扣减设置
    valid = 5  # 有效期设置

@unique
class GrowthConfigType(Enum):
    """
    :description: 成长值配置类型
    """
    init = 1  # 初始设置
    base = 2  # 基础设置
    deduct = 3  # 扣减设置
    valid = 4  # 有效期设置



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class TaoBaoRdsRefundModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(TaoBaoRdsRefundModel, self).__init__(TaoBaoRdsRefund, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class TaoBaoRdsRefund:
    def __init__(self):
        super(TaoBaoRdsRefund, self).__init__()
        self.refund_id = 0  # 退款号
        self.seller_nick = ""  # 卖家昵称
        self.buyer_nick = ""  # 买家昵称
        self.status = ""  # 状态
        self.tid = 0  # 订单号
        self.oid = 0  # 子订单号
        self.created = ""  # 创建时间
        self.modified = ""  # 修改时间
        self.jdp_hashcode = ""  # jdp_hashcode
        self.jdp_response = {}  # 接口返回值
        self.jdp_created = ""  # jdp_created
        self.jdp_modified = ""  # jdp_modified

    @classmethod
    def get_field_list(self):
        return ['refund_id', 'seller_nick', 'buyer_nick', 'status', 'tid', 'oid', 'created', 'modified', 'jdp_hashcode', 'jdp_response', 'jdp_created', 'jdp_modified']

    @classmethod
    def get_primary_key(self):
        return "refund_id"

    def __str__(self):
        return "taobao_rds_refund_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-07-15 17:20:19
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class AnalysisGoodsRelatedModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(AnalysisGoodsRelatedModel, self).__init__(AnalysisGoodsRelated, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class AnalysisGoodsRelated:
    def __init__(self):
        self.id = 0  # 唯一键,根据业务md5int生成
        self.business_id = 0  # 商家标识
        self.platform_id = 0  # 平台标识(1-淘宝 2-抖音 3-京东 4-微信)
        self.store_id = 0  # 店铺标识
        self.a_goods_id = ''  # A商品ID
        self.a_buyer_count = 0  # 购买A商品人数
        self.b_goods_id = ''  # B商品ID
        self.b_buyer_count = 0  # 购买B商品人数
        self.a_and_b_buyer_count = 0  # 同时购买A和B人数
        self.buy_rate = 0  # 购买连带率
        self.recommend_buyer_count = 0  # 可推荐人数
        self.rank_num = 0  # 排行号
        self.stat_date = 0  # 统计时间(20241231)
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'business_id', 'platform_id', 'store_id', 'a_goods_id', 'a_buyer_count', 'b_goods_id', 'b_buyer_count', 'a_and_b_buyer_count', 'buy_rate', 'recommend_buyer_count', 'rank_num', 'stat_date', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "analysis_goods_related_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-06 09:39:45
@LastEditTime: 2025-01-23 17:30:39
@LastEditors: HuangJianYi
@Description: 
"""

# 此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class CdpWorkInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(CdpWorkInfoModel, self).__init__(CdpWorkInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

    def start_work(self, store_id, work_name, progress_type=0, dependency_key='', scheme_id=0):
        """
        开始作业
        :param store_id: 店铺标识
        :param work_name: 作业名称
        :param progress_type: 当前进度值
        :param dependency_key: 依赖建
        :param scheme_id: 体系标识
        :return: 
        """
        if progress_type == 0:
            self.update_table("run_start_date=%s,progress_type=1", "scheme_id=%s and store_id=%s and work_name=%s", params=[TimeHelper.get_now_format_time(), scheme_id, store_id, work_name])
            self.delete_dependency_key(dependency_key)

    def end_work(self, store_id, work_name, run_desc='处理结束', dependency_key='', scheme_id=0):
        """
        结束作业
        :param store_id: 店铺标识
        :param work_name: 作业名称
        :param run_desc: 运行描述
        :param dependency_key: 依赖建
        :param scheme_id: 体系标识
        :return: 
        """
        self.update_table("run_desc=%s,run_end_date=%s,progress_type=2", "scheme_id=%s and store_id=%s and work_name=%s", params=[run_desc, TimeHelper.get_now_format_time(), scheme_id, store_id, work_name])
        self.delete_dependency_key(dependency_key)

    def run_work(self, store_id, work_name, scheme_id=0):
        """
        运行作业
        :param store_id: 店铺标识
        :param work_name: 作业名称
        :param scheme_id: 体系标识
        :return: 
        """
        return self.update_table("run_last_date=%s", "scheme_id=%s and store_id=%s and work_name=%s", params=[TimeHelper.get_now_format_time(), scheme_id, store_id, work_name])


class CdpWorkInfo:

    def __init__(self):
        super(CdpWorkInfo, self).__init__()
        self.id = 0  # id
        self.business_id = 0  # 商家标识
        self.scheme_id = 0  # 体系标识
        self.store_id = 0  # 店铺标识
        self.work_name = ""  # 作业名称(对应函数名)
        self.work_desc = ""  # 作业描述
        self.is_open = 0  # 是否开启(1-是 0-否)
        self.progress_type = 0  # 进度类型(0-未开始 1-进行中 2-已完成)
        self.step_value = 0  # 步骤值
        self.run_desc = ""  # 运行结果描述
        self.run_start_date = '1970-01-01 00:00:00.000'  # 开始运行时间
        self.run_end_date = '1970-01-01 00:00:00.000'  # 结束运行时间
        self.run_last_date = '1970-01-01 00:00:00.000'  # 最近运行时间
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'business_id', 'scheme_id', 'store_id', 'work_name', 'work_desc',
            'is_open', 'progress_type', 'step_value', 'run_desc',
            'run_start_date', 'run_end_date', 'run_last_date', 'create_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "cdp_work_info_tb"



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class CapStoreInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(CapStoreInfoModel, self).__init__(CapStoreInfo, sub_table)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class CapStoreInfo:

    def __init__(self):
        super(CapStoreInfo, self).__init__()
        self.id = 0  # id
        self.guid = ""  # guid
        self.business_id = 0  # 商家标识
        self.platform_id = 0 # 平台标识
        self.store_name = "" # 店铺名称
        self.seller_nick = ""  # 店铺主账号
        self.seller_id = "" # 店铺主账号id
        self.plat_store_id = "" # 平台店铺标识
        self.product_id = 0  # 产品标识
        self.extend_info = {}  # 扩展信息
        self.is_release = 0  # 是否发布(1-是 0-否)
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'guid', 'business_id','platform_id', 'store_name', 'seller_nick', 'seller_id', 'plat_store_id', 'product_id', 'extend_info', 'is_release', 'create_date', 'modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "cap_store_info_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-07-16 18:14:14
@LastEditors: HuangJianYi
@Description:
"""

from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class TradeOrderModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(TradeOrderModel, self).__init__(TradeOrder, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

class TradeOrder:
    def __init__(self):
        super(TradeOrder, self).__init__()
        self.id = 0  # id
        self.business_id = 0 # 商家标识
        self.store_id = 0 # 店铺标识
        self.plat_store_id = "" # 平台店铺标识
        self.user_id = "" # 客户ID
        self.ouid = "" # ouid
        self.platform_id = 0 # 平台标识
        self.main_pay_order_no = "" # 主订单号
        self.sub_pay_order_no = "" # 子订单号
        self.goods_code = "" # 商家编码
        self.goods_name = "" # 商品名称
        self.goods_pic = "" # 商品图片
        self.goods_id = "" # 商品标识
        self.sku_id = "" # sku_id
        self.buy_num = 0 # 购买数量
        self.goods_price = 0.0 # 商品价格
        self.order_price = 0.0 # 子订单金额
        self.pay_price = 0.0 # 子支付金额
        self.discount_price = 0.0 # 优惠金额
        self.order_status = "" # 子订单状态
        self.refund_status = "" # 退款状态
        self.refund_id = "" # 退款订单号

    @classmethod
    def get_field_list(self):
        return [
            'id', 'business_id', 'store_id', 'plat_store_id', 'user_id', 'ouid', 'platform_id', 'main_pay_order_no', 'sub_pay_order_no',
            'goods_code', 'goods_name', 'goods_pic', 'goods_id', 'sku_id','buy_num', 'goods_price', 'order_price', 'pay_price', 'discount_price', 'order_status', 'refund_status', 'refund_id'
            ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "trade_order_tb"



# -*- coding: utf-8 -*-
"""
@Author: 彩虹库处理类
@Date: 2024-10-22 13:43:02
@LastEditTime: 2025-04-17 15:24:10
@LastEditors: HuangJianYi
@Description: 彩虹库处理类 
"""
from seven_cloudapp_frame.handlers.frame_base import *


class RainbowHelper:
    """
    :description: 彩虹库处理类
    """
    def __init__(self,context=None,logging_error=None,logging_info=None):
        self.context = context
        self.logging_link_error = logging_error
        self.logging_link_info = logging_info

    def get_clear_text_phone(self, store_id, mix_mobile, is_cache=True):
        """
        :description: 获取明文手机号
        :param store_id: 店铺标识
        :param mix_mobile: 密文手机号
        :param is_cache: 是否使用缓存
        :return: invoke_result_data
        :last_editors: HuangJianYi
        """
        redis_key = f"tmall_member_clear_text_phone:mix_mobile_{mix_mobile}"
        invoke_result_data = InvokeResultData()
        try:
            redis_init = SevenHelper.redis_init()
            phone = ""
            if is_cache:
                phone = redis_init.get(redis_key)
            if not phone:
                rainbow_url = share_config.get_value("rainbow_url", "") + f"?store={store_id}&code={mix_mobile}"
                result = requests.get(url=rainbow_url)
                result_data = SevenHelper.json_loads(result.text) if result and result.reason == 'OK' else {}
                if not result_data or result_data.get("desc","") != "success":
                    invoke_result_data.success = False
                    invoke_result_data.error_message = result_data.get("desc", "彩虹库接口异常")
                    return invoke_result_data
                phone = result_data["data"]
                if phone:
                    redis_init.set(redis_key, str(phone), ex=3600)
            invoke_result_data.data = phone
        except Exception as ex:
            if self.context:
                self.context.logging_link_error("【获取明文手机号异常】" + traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error("【获取明文手机号异常】" + traceback.format_exc())
            invoke_result_data.success = False
            invoke_result_data.error_message = "获取手机号异常"
        return invoke_result_data



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-22 17:10:05
@LastEditTime: 2025-07-17 20:38:41
@LastEditors: HuangJianYi
@Description: 
"""
# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-06 18:48:03
@LastEditTime: 2024-11-08 17:49:47
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class TradeStatusInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(TradeStatusInfoModel, self).__init__(TradeStatusInfo, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class TradeStatusInfo:
    def __init__(self):
        super(TradeStatusInfo, self).__init__()
        self.id = 0 # id
        self.user_id = 0  # 客户ID
        self.business_id = 0 # 商家标识
        self.store_id = 0 # 店铺标识
        self.main_pay_order_no = '' # 主订单号
        self.order_status = '' # 订单状态
        self.platform_id = 0  # # 平台标识
        self.change_date = 0  # # 完成时间
        self.is_sync = 0 # 是否同步
        self.sync_date = '1970-01-01 00:00:00.000' # 同步时间

    @classmethod
    def get_field_list(self):
        return ['id','user_id', 'business_id', 'store_id', 'main_pay_order_no', 'order_status', 'platform_id', 'change_date', 'is_sync', 'sync_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "trade_status_info_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2024-11-14 15:10:45
@LastEditors: HuangJianYi
@Description: 体系信息表对应的模型类
"""

from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class SchemeInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(SchemeInfoModel, self).__init__(SchemeInfo, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class SchemeInfo:
    def __init__(self):
        super(SchemeInfo, self).__init__()
        self.id = 0  # id
        self.guid = ""  # guid
        self.business_id = 0  # 商家标识
        self.scheme_name = ""  # 体系名称
        self.level_rule_type = 1  # 等级规则类型(1-成长值等级 2-行为等级)
        self.operate_user_id = ""  # 操作用户标识
        self.operate_user_name = ""  # 操作用户名称
        self.extend_info = {}  # 拓展信息
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'guid', 'business_id', 'scheme_name', 'level_rule_type', 'operate_user_id', 'operate_user_name', 'extend_info', 'create_date', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "scheme_info_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-06-18 14:05:21
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class TradeInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(TradeInfoModel, self).__init__(TradeInfo, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class TradeInfo:
    def __init__(self):
        super(TradeInfo, self).__init__()
        self.id = 0 # id
        self.main_pay_order_no = "" # 主订单号
        self.store_id = 0 # 店铺标识
        self.business_id = 0 # 商家标识
        self.one_id = "" # one_id
        self.user_id = "" # 客户ID
        self.ouid = "" # ouid
        self.platform_id = 0 # 平台标识
        self.seller_nick = "" # 卖家昵称
        self.trade_type = "" # 交易类型
        self.step_trade_status = "" # 分阶段付款的订单状态
        self.order_price = 0.0 # 订单金额
        self.pay_price = 0.0 # 支付金额
        self.postage = 0.0 # 邮费
        self.discount_price = 0.0 # 优惠金额
        self.refund_price = 0.0 # 退款金额
        self.buy_num = 0 # 商品件数
        self.order_num = 0 # 子订单数量
        self.order_status = "" # 订单状态
        self.plat_store_id = "" # 平台店铺标识
        self.receiver = "" # 收货人
        self.telephone = "" # 收货人手机号
        self.receiver_province = "" # 收货人所在省份
        self.receiver_city = "" # 收货人所在城市
        self.receiver_county = "" # 收货人所在城区
        self.receiver_address = "" # 收货人所在地址
        self.buyer_remark = ""  # 买家备注
        self.seller_remark = "" # 卖家备注
        self.seller_flag = 0 # 卖家备注旗帜
        self.buyer_rate = 0 # 买家是否已评价(0-未评价 1-已评价)
        self.seller_rate = 0 # 卖家是否已评价(0-未评价 1-已评价)
        self.expand_card_basic_price = 0  # 购物金金额
        self.trade_source_types = "" # 交易内部来源。WAP(手机);HITAO(嗨淘);TOP(TOP平台);TAOBAO(普通淘宝);JHS(聚划算)一笔订单可能同时有以上多个标记，则以逗号分隔
        self.create_date = "1970-01-01 00:00:00.000" # 下单时间
        self.pay_date = "1970-01-01 00:00:00.000" # 付款时间
        self.consign_date = "1970-01-01 00:00:00.000" # 发货时间
        self.end_date = "1970-01-01 00:00:00.000" # 交易结束时间。交易成功时间(更新交易状态为成功的同时更新)/确认收货时间或者交易关闭时间
        self.source_type = 0 # 来源类型（1-历史备份数据导入 2-天猫会员通 3-抖音会员通）
        self.source_title = "" # 来源说明
        self.modify_date = "1970-01-01 00:00:00.000" # 修改时间(跟rds同步)
        self.is_incr_data = 0 # 是否增量数据(1-是 0-否)
        self.process_date = "1970-01-01 00:00:00.000" # 处理时间
        self.reward_process_status = 0  # 奖励处理状态：0-无需处理1-待处理2-已处理3-延迟处理10-订单异常
        self.refund_process_status = 0 # 退款处理状态(0-无需处理 1-待处理 2-已处理 10-订单异常)
        self.surplus_refund_price = 0 # 剩余退款金额

    @classmethod
    def get_field_list(self):
        return [
            'id', 'main_pay_order_no', 'store_id', 'business_id', 'one_id', 'user_id', 'ouid', 'platform_id', 'seller_nick', 'trade_type', 'step_trade_status', 'order_price', 'pay_price', 'postage', 'discount_price', 'refund_price', 'buy_num', 'order_num', 'order_status',
            'plat_store_id', 'receiver', 'telephone', 'receiver_province', 'receiver_city', 'receiver_county', 'receiver_address', 'buyer_remark', 'seller_remark', 'seller_flag', 'buyer_rate', 'seller_rate', 'expand_card_basic_price', 'trade_source_types', 'create_date',
            'pay_date', 'consign_date', 'end_date', 'source_type', 'source_title', 'modify_date', 'is_incr_data', 'process_date', 'reward_process_status', 'refund_process_status', 'surplus_refund_price'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "trade_info_tb"
